@@ -86,22 +86,24 @@ pub mod create_service_event_intend {
     #[serde(rename_all = "camelCase")]
     pub struct RequestBody {
         #[serde(default)]
-        pub host_user_id: Option<ID>,
+        pub host_user_ids: Option<Vec<ID>>,
         pub timestamp: i64,
         pub duration: i64,
         pub interval: i64,
     }
 
-    #[derive(Deserialize, Serialize)]
+    #[derive(Deserialize, Serialize, Debug)]
     #[serde(rename_all = "camelCase")]
     pub struct APIResponse {
-        pub selected_host: UserDTO,
+        pub selected_hosts: Vec<UserDTO>,
+        pub create_event_for_hosts: bool,
     }
 
     impl APIResponse {
-        pub fn new(selected_host: User) -> Self {
+        pub fn new(selected_hosts: Vec<User>, create_event_for_hosts: bool) -> Self {
             Self {
-                selected_host: UserDTO::new(selected_host),
+                selected_hosts: selected_hosts.into_iter().map(UserDTO::new).collect(),
+                create_event_for_hosts,
             }
         }
     }
@@ -167,7 +169,7 @@ pub mod get_service_bookingslots {
         pub end_date: String,
     }
 
-    #[derive(Deserialize, Serialize)]
+    #[derive(Deserialize, Serialize, Debug)]
     #[serde(rename_all = "camelCase")]
     pub struct ServiceBookingSlotDTO {
         pub start: i64,
@@ -185,7 +187,7 @@ pub mod get_service_bookingslots {
         }
     }
 
-    #[derive(Deserialize, Serialize)]
+    #[derive(Deserialize, Serialize, Debug)]
     #[serde(rename_all = "camelCase")]
     pub struct ServiceBookingSlotsDateDTO {
         pub date: String,
@@ -205,7 +207,7 @@ pub mod get_service_bookingslots {
         }
     }
 
-    #[derive(Deserialize, Serialize)]
+    #[derive(Deserialize, Serialize, Debug)]
     #[serde(rename_all = "camelCase")]
     pub struct APIResponse {
         pub dates: Vec<ServiceBookingSlotsDateDTO>,
